<div align="center">

<a alt="PyPackIT Test1: A New Python Project" href="https://AAriam.github.io/PyPackIT-Test1"><img alt="PyPackIT Test1: A New Python Project" src="https://raw.githubusercontent.com/AAriam/PyPackIT-Test1/main/docs/website/source/_media/logo/full_light.svg" title="Welcome to PyPackIT Test1! Click to visit our website and learn more." width="80%" /></a>

</div>

<div align="center">

<hr width="80%" />

<a alt="Intro" href="https://AAriam.github.io/PyPackIT-Test1/intro"><img alt="Intro" height="33px" src="https://img.shields.io/static/v1?message=Intro&amp;label=&amp;style=for-the-badge&amp;color=%230F3460" title="Introduction and Background" /></a>&nbsp;&nbsp;<a alt="Manual" href="https://AAriam.github.io/PyPackIT-Test1/manual"><img alt="Manual" height="33px" src="https://img.shields.io/static/v1?message=Manual&amp;label=&amp;style=for-the-badge&amp;color=%230F3460" title="User Manual" /></a>&nbsp;&nbsp;<a alt="News" href="https://AAriam.github.io/PyPackIT-Test1/news"><img alt="News" height="33px" src="https://img.shields.io/static/v1?message=News&amp;label=&amp;style=for-the-badge&amp;color=%230F3460" title="Latest News and Releases" /></a>&nbsp;&nbsp;<a alt="Contribute" href="https://AAriam.github.io/PyPackIT-Test1/contribute"><img alt="Contribute" height="33px" src="https://img.shields.io/static/v1?message=Contribute&amp;label=&amp;style=for-the-badge&amp;color=%230F3460" title="How to Contribute" /></a>&nbsp;&nbsp;<a alt="About" href="https://AAriam.github.io/PyPackIT-Test1/about"><img alt="About" height="33px" src="https://img.shields.io/static/v1?message=About&amp;label=&amp;style=for-the-badge&amp;color=%230F3460" title="About the Project" /></a>&nbsp;&nbsp;<a alt="Help" href="https://AAriam.github.io/PyPackIT-Test1/help"><img alt="Help" height="33px" src="https://img.shields.io/static/v1?message=Help&amp;label=&amp;style=for-the-badge&amp;color=%230F3460" title="Get Help and Support" /></a>

<hr width="100%" />

</div>

<p align="justify">
   Welcome to PyPackIT Test1 powered by <a href="https://pypackit.repodynamics.com/">PyPackIT</a>. Replace this text with a short abstract of PyPackIT Test1, describing its purpose and main features. By default, this text is displayed on the repository's main README file, on the homepage of the project's website, on the project's PyPI and TestPyPI pages, and on the package's main docstring. Like all other entries in the repository's control center, this text can also contain dynamic references to other entries, using the <code>${‎{ json-path.to.value }}$</code> syntax. By default, the first occurrence of the name of the project in this text is styled as strong and linked to the project's website.
</p>

<img alt="Keywords: " height="23px" src="https://img.shields.io/static/v1?message=Keywords%3A%20&amp;label=&amp;style=plastic&amp;color=%232c2e30" />&nbsp;&nbsp;<img alt="First Keyword" height="23px" src="https://img.shields.io/static/v1?message=First%20Keyword&amp;label=&amp;color=%5B%27%230F3460%27%2C%20%27%23562B08%27%5D" />&nbsp;<img alt="Second Keyword" height="23px" src="https://img.shields.io/static/v1?message=Second%20Keyword&amp;label=&amp;color=%5B%27%230F3460%27%2C%20%27%23562B08%27%5D" />&nbsp;<img alt="Third Keyword" height="23px" src="https://img.shields.io/static/v1?message=Third%20Keyword&amp;label=&amp;color=%5B%27%230F3460%27%2C%20%27%23562B08%27%5D" />&nbsp;<img alt="Fourth Keyword" height="23px" src="https://img.shields.io/static/v1?message=Fourth%20Keyword&amp;label=&amp;color=%5B%27%230F3460%27%2C%20%27%23562B08%27%5D" />&nbsp;<img alt="Fifth Keyword" height="23px" src="https://img.shields.io/static/v1?message=Fifth%20Keyword&amp;label=&amp;color=%5B%27%230F3460%27%2C%20%27%23562B08%27%5D" />&nbsp;<img alt="Sixth Keyword" height="23px" src="https://img.shields.io/static/v1?message=Sixth%20Keyword&amp;label=&amp;color=%5B%27%230F3460%27%2C%20%27%23562B08%27%5D" />

<div align="center">

<hr width="100%" />

<a alt="Overview" href="https://AAriam.github.io/PyPackIT-Test1/intro/overview"><img alt="Overview" height="33px" src="https://img.shields.io/static/v1?message=Overview&amp;label=&amp;style=for-the-badge&amp;color=%23562B08" title="Project Overview" /></a>&nbsp;&nbsp;<a alt="Install" href="https://AAriam.github.io/PyPackIT-Test1/manual/install"><img alt="Install" height="33px" src="https://img.shields.io/static/v1?message=Install&amp;label=&amp;style=for-the-badge&amp;color=%23562B08" title="Installation Instructions" /></a>&nbsp;&nbsp;<a alt="Releases" href="https://AAriam.github.io/PyPackIT-Test1/news/category/release"><img alt="Releases" height="33px" src="https://img.shields.io/static/v1?message=Releases&amp;label=&amp;style=for-the-badge&amp;color=%23562B08" title="Release Notes and Changelogs" /></a>&nbsp;&nbsp;<a alt="Contact" href="https://AAriam.github.io/PyPackIT-Test1/about/contact"><img alt="Contact" height="33px" src="https://img.shields.io/static/v1?message=Contact&amp;label=&amp;style=for-the-badge&amp;color=%23562B08" title="Contact Information" /></a>

<hr width="80%" />

</div>

<br>

<h2>

Highlights

</h2>

<img align="left" alt="First Key Feature" height="30px" src="https://img.shields.io/static/v1?message=First%20Key%20Feature&amp;label=&amp;style=for-the-badge&amp;color=%5B%27%230F3460%27%2C%20%27%23562B08%27%5D" /><p align="justify">
   Description of the first key feature of PyPackIT Test1. By default, these highlights are displayed on the repository's main README file, on the homepage of the project's website, and on the project's PyPI and TestPyPI pages.
</p>

<img align="left" alt="Second Key Feature" height="30px" src="https://img.shields.io/static/v1?message=Second%20Key%20Feature&amp;label=&amp;style=for-the-badge&amp;color=%5B%27%230F3460%27%2C%20%27%23562B08%27%5D" /><p align="justify">
   Description of the second key feature of PyPackIT Test1. For aesthetic reasons, it is recommended to keep the descriptions of all items in this list approximately the same length.
</p>

<img align="left" alt="Third Key Feature" height="30px" src="https://img.shields.io/static/v1?message=Third%20Key%20Feature&amp;label=&amp;style=for-the-badge&amp;color=%5B%27%230F3460%27%2C%20%27%23562B08%27%5D" /><p align="justify">
   Description of the third key feature of PyPackIT Test1. You can add as many keynotes as you want. However, in order to keep the READMEs clean and tidy, it is recommended to keep the number of keynotes between 3 and 7.
</p>

<hr />

<a alt="PyPackIT Test1" href="https://AAriam.github.io/PyPackIT-Test1"><img align="left" alt="PyPackIT Test1" src="https://img.shields.io/badge/dynamic/json?url=https%3A%2F%2Fraw.githubusercontent.com%2FAAriam%2FPyPackIT-Test1%2Fmain%2F.github%2F.repodynamics%2Fmetadata.json&amp;query=%24.copyright&amp;label=PyPackIT%20Test1&amp;style=for-the-badge&amp;color=%230F3460&amp;logo=data%3Aimage%2Fsvg%2Bxml%3Bbase64%2CPD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyBpZD0iTGF5ZXJfMiIgZGF0YS1uYW1lPSJMYXllciAyIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCA4OSA4OSI%2BCiAgPGRlZnM%2BCiAgICA8c3R5bGU%2BCiAgICAgIC5jbHMtMSB7CiAgICAgICAgZmlsbDogIzAwOTI0NTsKICAgICAgfQoKICAgICAgLmNscy0xLCAuY2xzLTIgewogICAgICAgIHN0cm9rZTogI2ZmZjsKICAgICAgICBzdHJva2UtbWl0ZXJsaW1pdDogMTA7CiAgICAgIH0KCiAgICAgIC5jbHMtMiB7CiAgICAgICAgZmlsbDogI2MxMjcyZDsKICAgICAgfQogICAgPC9zdHlsZT4KICA8L2RlZnM% %2BCjwvc3ZnPgo%3D" title="PyPackIT Test1: © 2024 Armin Ariamajd" /></a>&nbsp;<a alt="SPDX-License-Identifier: MIT" href="https://AAriam.github.io/PyPackIT-Test1/about/license"><img align="right" alt="SPDX-License-Identifier: MIT" src="https://img.shields.io/static/v1?message=MIT&amp;label=License&amp;style=for-the-badge&amp;color=%23562B08" title="SPDX-License-Identifier: MIT" /></a>

<a alt="Powered by PyPackIT" href="https://pypackit.repodynamics.com"><img align="right" alt="Powered by PyPackIT" src="https://img.shields.io/static/v1?message=PyPackIT&amp;logo=data%3Aimage%2Fpng%3Bbase64%2CiVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAACXBIWXMAAAsPAAALDwGS%2BQOlAAADxklEQVRYhb1XbWxTZRR%2B3vvR3rt%2BOsJ2M5CWrKIxZJsm%2FgITk0XBjYQ4IJshAcJHjIq4HyyKgjJBPiLqwg8Tk6L80qATgwkLGpUE94OYSBgSIZnTFoK93VxhpV1v73s%2FTGu6rOu69nZlz6%2Fzvue85zw55z73vZeYpgkraDr85IX7NLEGFHDrrtDQ8d%2BWW0owA4yV4LVH2juHyV9rQuYthPQwrqnX%2FU%2F3PHNswQhEmbFNCpS8vZgWW71gBFJECRQkIMyK%2BRDgZtvsOtV2Om5OBmomPZv795wLz%2FRLpB5gTMiIImEkF8%2BHQEEHXvr0xdXjzsjWO67QqiSX6J3uSyPdLEDAI2jc9Tj72AGBCPOpnUVBB1Re6UrZkvDEa5HkkgXzlcw6XOr9OZixl%2FesOATDmopKEtBZKi2JBX7VVTIa4aLr5pW9DBSMQGPVAAFu1FDXTw%2B6eAazqsCpeK%2BWOti6%2FzmfYiqlwkpiVhWUAzuxvyDrUfixbM7oXR%2Bs7055wttEkcDBi1yN%2FlD7kc3np5RVMYHZsHbP853%2Fmndes4mGkxe1gCDCwTvTgGMMuosBXATC3eaMsrbljlt6ETFgksV8ra8%2F6%2Ft94npwOHVzVZgON8tmyDHO3kKCG82L073y1oNft%2FsqIsCD%2F7OYTzXUlyNKxFkqh%2B4eAwjeya2rNoIJbaKl3FhTTKx%2Fv7%2BjlVXcgqUOzAXVoFK5sWTS2ff2xrN%2BtvbuxgICJjGn2iiL%2F2DDhx3d5SQ1YJRsfwbcmC96cNP5wxm7p%2B3cYHYE%2Bz7f0UkpWpL2%2BEqGZRqDr37Rt%2BVkV1mFc6AGbcyYdTYp4bM1fGMngKAxUKm8wcRolhyj2cHG607nEXo3%2BIqZXirjnn0c96kKQZa%2Bt1J4Jlyse%2BTH45enZLbjRFuQ3Fv2BhB7SkiJV492%2FvBmHoHenZ%2BQfZ%2Ft7PZwHkmkWEx14z0rBUNqGG171xXt1qm9A4MABov5syM4uj3YZ6VoNVE1FVSKigkY0CO5D5IbqZsfy%2Blo1nawjpIX2XRUTODCoYEzEluftUNKGIpR2c1Y9RGwhEssGAE7sQ1NXwusADfr%2BWXBCHgZb568logN0e9ODJypKoEYH5u6ZDRoEg9%2BJLe%2BfGxwd5OwMuQXfPCLPjQIDfutFM%2Bg5G14W7jd0XTyiRZCWc8I%2B3f9ozQgT%2FcPfXTlwfwbUkb9tja9CHFuwjVsH2m%2BZvvDn9m3gZeLnakqgS93nw07NFf%2BQ2YK8Jre%2FmoSmHMETs351lL94a%2BSuupQqY46bdHFSwf%2B%2FympCgD8BxQORGJUan2aAAAAAElFTkSuQmCC&amp;color=rgb%280%2C%20100%2C%200%29&amp;label=Powered%20By&amp;style=for-the-badge" title="Automated project management and DevOps by PyPackIT." /></a>
